@@ -39,10 +39,9 @@ class PubSub:
             return success
 
     async def subscribe(self, datakind: str, callback: Callable[[dict], Awaitable]) -> None:
-        channel, = await self.redis.psubscribe(datakind)
+        channel, = await self.redis.psubscribe(parser.add_main_prefix(datakind))
         self.logger.info('Service has subscribed to {}.'.format(datakind))
         while await channel.wait_message():
-            self.logger.debug('New {}.'.format(datakind))
             try:
                 _, message = await channel.get(encoding='utf-8')
                 asyncio.create_task(callback(await parser.decode_message(message, self.custom_data_decoder)))
