@@ -34,8 +34,6 @@ def encode_pandas(dataframe: pd.DataFrame) -> str:
         try:
             if pdtypes.is_numeric_dtype(dataframe[col]):
                 dataframe[col] = dataframe[col].round().astype('int')
-            else:
-                dataframe[col] = dataframe[col].map(json.dumps)
         except:
             pass
     dataframe.replace(MessageData.nan, '', inplace=True)
@@ -86,12 +84,6 @@ def sync_decode_message(message: str, custom_data_decoder: Callable = None) -> d
 
 def decode_pandas(data: str) -> pd.DataFrame:
     dataframe = pd.read_csv(io.StringIO(data), sep=MessageData.csvseparator, index_col=0)
-    for col in dataframe.columns:
-        try:
-            if not pdtypes.is_numeric_dtype(dataframe[col]):
-                dataframe[col] = dataframe[col].map(json.loads)
-        except:
-            pass
     dataframe.replace(MessageData.nan, np.NaN, inplace=True)
     dataframe.replace(str(MessageData.nan), np.NaN, inplace=True)
     try:
